# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: configrelease.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from ..service_manage import service_pb2 as service__pb2
from ..fault_tolerance import circuitbreaker_pb2 as circuitbreaker__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63onfigrelease.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\rservice.proto\x1a\x14\x63ircuitbreaker.proto\"\xb3\x01\n\rConfigRelease\x12\x1c\n\x07service\x18\x01 \x01(\x0b\x32\x0b.v1.Service\x12+\n\x05\x63time\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x0e\x63ircuitBreaker\x18\x04 \x01(\x0b\x32\x12.v1.CircuitBreaker\"^\n\x11\x43onfigWithService\x12\x1d\n\x08services\x18\x01 \x03(\x0b\x32\x0b.v1.Service\x12*\n\x0e\x63ircuitBreaker\x18\x02 \x01(\x0b\x32\x12.v1.CircuitBreakerB\x93\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\x12\x43onfigReleaseProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'configrelease_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\022ConfigReleaseProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _globals['_CONFIGRELEASE']._serialized_start=97
  _globals['_CONFIGRELEASE']._serialized_end=276
  _globals['_CONFIGWITHSERVICE']._serialized_start=278
  _globals['_CONFIGWITHSERVICE']._serialized_end=372
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: config_file_response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from ..config_manage import config_file_pb2 as config__file__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63onfig_file_response.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x63onfig_file.proto\"n\n\x14\x43onfigSimpleResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xe0\x02\n\x0e\x43onfigResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x0f\x63onfigFileGroup\x18\x03 \x01(\x0b\x32\x13.v1.ConfigFileGroup\x12\"\n\nconfigFile\x18\x04 \x01(\x0b\x32\x0e.v1.ConfigFile\x12\x30\n\x11\x63onfigFileRelease\x18\x05 \x01(\x0b\x32\x15.v1.ConfigFileRelease\x12>\n\x18\x63onfigFileReleaseHistory\x18\x06 \x01(\x0b\x32\x1c.v1.ConfigFileReleaseHistory\x12\x32\n\x12\x63onfigFileTemplate\x18\x07 \x01(\x0b\x32\x16.v1.ConfigFileTemplate\"\xc6\x01\n\x18\x43onfigBatchWriteResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05total\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12%\n\tresponses\x18\x04 \x03(\x0b\x32\x12.v1.ConfigResponse\"\x9d\x03\n\x18\x43onfigBatchQueryResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05total\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12-\n\x10\x63onfigFileGroups\x18\x04 \x03(\x0b\x32\x13.v1.ConfigFileGroup\x12#\n\x0b\x63onfigFiles\x18\x05 \x03(\x0b\x32\x0e.v1.ConfigFile\x12\x31\n\x12\x63onfigFileReleases\x18\x06 \x03(\x0b\x32\x15.v1.ConfigFileRelease\x12@\n\x1a\x63onfigFileReleaseHistories\x18\x07 \x03(\x0b\x32\x1c.v1.ConfigFileReleaseHistory\x12\x33\n\x13\x63onfigFileTemplates\x18\x08 \x03(\x0b\x32\x16.v1.ConfigFileTemplate\"\x9c\x01\n\x14\x43onfigClientResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\nconfigFile\x18\x03 \x01(\x0b\x32\x18.v1.ClientConfigFileInfo\"\xf0\x01\n\x14\x43onfigImportResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x11\x63reateConfigFiles\x18\x03 \x03(\x0b\x32\x0e.v1.ConfigFile\x12\'\n\x0fskipConfigFiles\x18\x04 \x03(\x0b\x32\x0e.v1.ConfigFile\x12,\n\x14overwriteConfigFiles\x18\x05 \x03(\x0b\x32\x0e.v1.ConfigFile\"\x99\x01\n\x14\x43onfigExportResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.BytesValue\"\xaa\x01\n\x1e\x43onfigEncryptAlgorithmResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nalgorithms\x18\x03 \x03(\x0b\x32\x1c.google.protobuf.StringValue\"\x8c\x02\n\x18\x43onfigClientListResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08revision\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x11\n\tnamespace\x18\x04 \x01(\t\x12\r\n\x05group\x18\x05 \x01(\t\x12\x46\n\x11\x63onfig_file_infos\x18\x06 \x03(\x0b\x32\x18.v1.ClientConfigFileInfoR\x11\x63onfig_file_infosB\x96\x01\n6com.tencent.polaris.specification.api.v1.config.manageB\x17\x43onfigFileResponseProtoZCgithub.com/polarismesh/specification/source/go/api/v1/config_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'config_file_response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n6com.tencent.polaris.specification.api.v1.config.manageB\027ConfigFileResponseProtoZCgithub.com/polarismesh/specification/source/go/api/v1/config_manage'
  _globals['_CONFIGSIMPLERESPONSE']._serialized_start=85
  _globals['_CONFIGSIMPLERESPONSE']._serialized_end=195
  _globals['_CONFIGRESPONSE']._serialized_start=198
  _globals['_CONFIGRESPONSE']._serialized_end=550
  _globals['_CONFIGBATCHWRITERESPONSE']._serialized_start=553
  _globals['_CONFIGBATCHWRITERESPONSE']._serialized_end=751
  _globals['_CONFIGBATCHQUERYRESPONSE']._serialized_start=754
  _globals['_CONFIGBATCHQUERYRESPONSE']._serialized_end=1167
  _globals['_CONFIGCLIENTRESPONSE']._serialized_start=1170
  _globals['_CONFIGCLIENTRESPONSE']._serialized_end=1326
  _globals['_CONFIGIMPORTRESPONSE']._serialized_start=1329
  _globals['_CONFIGIMPORTRESPONSE']._serialized_end=1569
  _globals['_CONFIGEXPORTRESPONSE']._serialized_start=1572
  _globals['_CONFIGEXPORTRESPONSE']._serialized_end=1725
  _globals['_CONFIGENCRYPTALGORITHMRESPONSE']._serialized_start=1728
  _globals['_CONFIGENCRYPTALGORITHMRESPONSE']._serialized_end=1898
  _globals['_CONFIGCLIENTLISTRESPONSE']._serialized_start=1901
  _globals['_CONFIGCLIENTLISTRESPONSE']._serialized_end=2169
# @@protoc_insertion_point(module_scope)



from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AuthAction(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    ONLY_READ: _ClassVar[AuthAction]
    READ_WRITE: _ClassVar[AuthAction]

class ResourceType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    Namespaces: _ClassVar[ResourceType]
    Services: _ClassVar[ResourceType]
    ConfigGroups: _ClassVar[ResourceType]
ONLY_READ: AuthAction
READ_WRITE: AuthAction
Namespaces: ResourceType
Services: ResourceType
ConfigGroups: ResourceType

class LoginRequest(_message.Message):
    __slots__ = ["owner", "name", "password"]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    owner: _wrappers_pb2.StringValue
    name: _wrappers_pb2.StringValue
    password: _wrappers_pb2.StringValue
    def __init__(self, owner: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., password: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class LoginResponse(_message.Message):
    __slots__ = ["user_id", "name", "role", "owner_id", "token"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    OWNER_ID_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    user_id: _wrappers_pb2.StringValue
    name: _wrappers_pb2.StringValue
    role: _wrappers_pb2.StringValue
    owner_id: _wrappers_pb2.StringValue
    token: _wrappers_pb2.StringValue
    def __init__(self, user_id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., role: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., owner_id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., token: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class User(_message.Message):
    __slots__ = ["id", "name", "password", "owner", "source", "auth_token", "token_enable", "comment", "ctime", "mtime", "user_type", "mobile", "email"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    AUTH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOKEN_ENABLE_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    USER_TYPE_FIELD_NUMBER: _ClassVar[int]
    MOBILE_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.StringValue
    name: _wrappers_pb2.StringValue
    password: _wrappers_pb2.StringValue
    owner: _wrappers_pb2.StringValue
    source: _wrappers_pb2.StringValue
    auth_token: _wrappers_pb2.StringValue
    token_enable: _wrappers_pb2.BoolValue
    comment: _wrappers_pb2.StringValue
    ctime: _wrappers_pb2.StringValue
    mtime: _wrappers_pb2.StringValue
    user_type: _wrappers_pb2.StringValue
    mobile: _wrappers_pb2.StringValue
    email: _wrappers_pb2.StringValue
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., password: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., owner: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., source: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., auth_token: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., token_enable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., ctime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., mtime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., user_type: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., mobile: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., email: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class ModifyUserPassword(_message.Message):
    __slots__ = ["id", "old_password", "new_password"]
    ID_FIELD_NUMBER: _ClassVar[int]
    OLD_PASSWORD_FIELD_NUMBER: _ClassVar[int]
    NEW_PASSWORD_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.StringValue
    old_password: _wrappers_pb2.StringValue
    new_password: _wrappers_pb2.StringValue
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., old_password: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., new_password: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class UserGroupRelation(_message.Message):
    __slots__ = ["group_id", "users"]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    group_id: _wrappers_pb2.StringValue
    users: _containers.RepeatedCompositeFieldContainer[User]
    def __init__(self, group_id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., users: _Optional[_Iterable[_Union[User, _Mapping]]] = ...) -> None: ...

class UserGroup(_message.Message):
    __slots__ = ["id", "name", "owner", "auth_token", "token_enable", "comment", "ctime", "mtime", "relation", "user_count"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    AUTH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOKEN_ENABLE_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    RELATION_FIELD_NUMBER: _ClassVar[int]
    USER_COUNT_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.StringValue
    name: _wrappers_pb2.StringValue
    owner: _wrappers_pb2.StringValue
    auth_token: _wrappers_pb2.StringValue
    token_enable: _wrappers_pb2.BoolValue
    comment: _wrappers_pb2.StringValue
    ctime: _wrappers_pb2.StringValue
    mtime: _wrappers_pb2.StringValue
    relation: UserGroupRelation
    user_count: _wrappers_pb2.UInt32Value
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., owner: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., auth_token: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., token_enable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., ctime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., mtime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., relation: _Optional[_Union[UserGroupRelation, _Mapping]] = ..., user_count: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ...) -> None: ...

class ModifyUserGroup(_message.Message):
    __slots__ = ["id", "owner", "name", "auth_token", "token_enable", "comment", "add_relations", "remove_relations"]
    ID_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    AUTH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOKEN_ENABLE_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    ADD_RELATIONS_FIELD_NUMBER: _ClassVar[int]
    REMOVE_RELATIONS_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.StringValue
    owner: _wrappers_pb2.StringValue
    name: _wrappers_pb2.StringValue
    auth_token: _wrappers_pb2.StringValue
    token_enable: _wrappers_pb2.BoolValue
    comment: _wrappers_pb2.StringValue
    add_relations: UserGroupRelation
    remove_relations: UserGroupRelation
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., owner: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., auth_token: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., token_enable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., add_relations: _Optional[_Union[UserGroupRelation, _Mapping]] = ..., remove_relations: _Optional[_Union[UserGroupRelation, _Mapping]] = ...) -> None: ...

class Principal(_message.Message):
    __slots__ = ["id", "name"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.StringValue
    name: _wrappers_pb2.StringValue
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class Principals(_message.Message):
    __slots__ = ["users", "groups"]
    USERS_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    users: _containers.RepeatedCompositeFieldContainer[Principal]
    groups: _containers.RepeatedCompositeFieldContainer[Principal]
    def __init__(self, users: _Optional[_Iterable[_Union[Principal, _Mapping]]] = ..., groups: _Optional[_Iterable[_Union[Principal, _Mapping]]] = ...) -> None: ...

class StrategyResourceEntry(_message.Message):
    __slots__ = ["id", "namespace", "name"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    name: _wrappers_pb2.StringValue
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class StrategyResources(_message.Message):
    __slots__ = ["strategy_id", "namespaces", "services", "config_groups"]
    STRATEGY_ID_FIELD_NUMBER: _ClassVar[int]
    NAMESPACES_FIELD_NUMBER: _ClassVar[int]
    SERVICES_FIELD_NUMBER: _ClassVar[int]
    CONFIG_GROUPS_FIELD_NUMBER: _ClassVar[int]
    strategy_id: _wrappers_pb2.StringValue
    namespaces: _containers.RepeatedCompositeFieldContainer[StrategyResourceEntry]
    services: _containers.RepeatedCompositeFieldContainer[StrategyResourceEntry]
    config_groups: _containers.RepeatedCompositeFieldContainer[StrategyResourceEntry]
    def __init__(self, strategy_id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespaces: _Optional[_Iterable[_Union[StrategyResourceEntry, _Mapping]]] = ..., services: _Optional[_Iterable[_Union[StrategyResourceEntry, _Mapping]]] = ..., config_groups: _Optional[_Iterable[_Union[StrategyResourceEntry, _Mapping]]] = ...) -> None: ...

class AuthStrategy(_message.Message):
    __slots__ = ["id", "name", "principals", "resources", "action", "comment", "owner", "ctime", "mtime", "auth_token", "default_strategy"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PRINCIPALS_FIELD_NUMBER: _ClassVar[int]
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    AUTH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_STRATEGY_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.StringValue
    name: _wrappers_pb2.StringValue
    principals: Principals
    resources: StrategyResources
    action: AuthAction
    comment: _wrappers_pb2.StringValue
    owner: _wrappers_pb2.StringValue
    ctime: _wrappers_pb2.StringValue
    mtime: _wrappers_pb2.StringValue
    auth_token: _wrappers_pb2.StringValue
    default_strategy: _wrappers_pb2.BoolValue
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., principals: _Optional[_Union[Principals, _Mapping]] = ..., resources: _Optional[_Union[StrategyResources, _Mapping]] = ..., action: _Optional[_Union[AuthAction, str]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., owner: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., ctime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., mtime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., auth_token: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., default_strategy: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...) -> None: ...

class ModifyAuthStrategy(_message.Message):
    __slots__ = ["id", "name", "add_principals", "remove_principals", "add_resources", "remove_resources", "action", "comment", "owner"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ADD_PRINCIPALS_FIELD_NUMBER: _ClassVar[int]
    REMOVE_PRINCIPALS_FIELD_NUMBER: _ClassVar[int]
    ADD_RESOURCES_FIELD_NUMBER: _ClassVar[int]
    REMOVE_RESOURCES_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.StringValue
    name: _wrappers_pb2.StringValue
    add_principals: Principals
    remove_principals: Principals
    add_resources: StrategyResources
    remove_resources: StrategyResources
    action: AuthAction
    comment: _wrappers_pb2.StringValue
    owner: _wrappers_pb2.StringValue
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., add_principals: _Optional[_Union[Principals, _Mapping]] = ..., remove_principals: _Optional[_Union[Principals, _Mapping]] = ..., add_resources: _Optional[_Union[StrategyResources, _Mapping]] = ..., remove_resources: _Optional[_Union[StrategyResources, _Mapping]] = ..., action: _Optional[_Union[AuthAction, str]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., owner: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ServiceContract(_message.Message):
    __slots__ = ["id", "name", "namespace", "service", "protocol", "version", "revision", "content", "interfaces", "ctime", "mtime", "status"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    INTERFACES_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    namespace: str
    service: str
    protocol: str
    version: str
    revision: str
    content: str
    interfaces: _containers.RepeatedCompositeFieldContainer[InterfaceDescriptor]
    ctime: str
    mtime: str
    status: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., namespace: _Optional[str] = ..., service: _Optional[str] = ..., protocol: _Optional[str] = ..., version: _Optional[str] = ..., revision: _Optional[str] = ..., content: _Optional[str] = ..., interfaces: _Optional[_Iterable[_Union[InterfaceDescriptor, _Mapping]]] = ..., ctime: _Optional[str] = ..., mtime: _Optional[str] = ..., status: _Optional[str] = ...) -> None: ...

class InterfaceDescriptor(_message.Message):
    __slots__ = ["id", "method", "path", "content", "source", "revision", "ctime", "mtime"]
    class Source(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNKNOWN: _ClassVar[InterfaceDescriptor.Source]
        Manual: _ClassVar[InterfaceDescriptor.Source]
        Client: _ClassVar[InterfaceDescriptor.Source]
    UNKNOWN: InterfaceDescriptor.Source
    Manual: InterfaceDescriptor.Source
    Client: InterfaceDescriptor.Source
    ID_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    id: str
    method: str
    path: str
    content: str
    source: InterfaceDescriptor.Source
    revision: str
    ctime: str
    mtime: str
    def __init__(self, id: _Optional[str] = ..., method: _Optional[str] = ..., path: _Optional[str] = ..., content: _Optional[str] = ..., source: _Optional[_Union[InterfaceDescriptor.Source, str]] = ..., revision: _Optional[str] = ..., ctime: _Optional[str] = ..., mtime: _Optional[str] = ...) -> None: ...



from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf import any_pb2 as _any_pb2
from ..model import model_pb2 as _model_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RoutingPolicy(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    RulePolicy: _ClassVar[RoutingPolicy]
    MetadataPolicy: _ClassVar[RoutingPolicy]
RulePolicy: RoutingPolicy
MetadataPolicy: RoutingPolicy

class Routing(_message.Message):
    __slots__ = ["service", "namespace", "inbounds", "outbounds", "ctime", "mtime", "revision", "service_token", "rules"]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    INBOUNDS_FIELD_NUMBER: _ClassVar[int]
    OUTBOUNDS_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    SERVICE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    RULES_FIELD_NUMBER: _ClassVar[int]
    service: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    inbounds: _containers.RepeatedCompositeFieldContainer[Route]
    outbounds: _containers.RepeatedCompositeFieldContainer[Route]
    ctime: _wrappers_pb2.StringValue
    mtime: _wrappers_pb2.StringValue
    revision: _wrappers_pb2.StringValue
    service_token: _wrappers_pb2.StringValue
    rules: _containers.RepeatedCompositeFieldContainer[RouteRule]
    def __init__(self, service: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., inbounds: _Optional[_Iterable[_Union[Route, _Mapping]]] = ..., outbounds: _Optional[_Iterable[_Union[Route, _Mapping]]] = ..., ctime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., mtime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., revision: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., service_token: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., rules: _Optional[_Iterable[_Union[RouteRule, _Mapping]]] = ...) -> None: ...

class Route(_message.Message):
    __slots__ = ["sources", "destinations", "extendInfo"]
    class ExtendInfoEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    SOURCES_FIELD_NUMBER: _ClassVar[int]
    DESTINATIONS_FIELD_NUMBER: _ClassVar[int]
    EXTENDINFO_FIELD_NUMBER: _ClassVar[int]
    sources: _containers.RepeatedCompositeFieldContainer[Source]
    destinations: _containers.RepeatedCompositeFieldContainer[Destination]
    extendInfo: _containers.ScalarMap[str, str]
    def __init__(self, sources: _Optional[_Iterable[_Union[Source, _Mapping]]] = ..., destinations: _Optional[_Iterable[_Union[Destination, _Mapping]]] = ..., extendInfo: _Optional[_Mapping[str, str]] = ...) -> None: ...

class Source(_message.Message):
    __slots__ = ["service", "namespace", "metadata"]
    class MetadataEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _model_pb2.MatchString
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ...) -> None: ...
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    service: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    metadata: _containers.MessageMap[str, _model_pb2.MatchString]
    def __init__(self, service: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., metadata: _Optional[_Mapping[str, _model_pb2.MatchString]] = ...) -> None: ...

class Destination(_message.Message):
    __slots__ = ["service", "namespace", "metadata", "priority", "weight", "transfer", "isolate", "name"]
    class MetadataEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _model_pb2.MatchString
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ...) -> None: ...
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_FIELD_NUMBER: _ClassVar[int]
    ISOLATE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    service: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    metadata: _containers.MessageMap[str, _model_pb2.MatchString]
    priority: _wrappers_pb2.UInt32Value
    weight: _wrappers_pb2.UInt32Value
    transfer: _wrappers_pb2.StringValue
    isolate: _wrappers_pb2.BoolValue
    name: _wrappers_pb2.StringValue
    def __init__(self, service: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., metadata: _Optional[_Mapping[str, _model_pb2.MatchString]] = ..., priority: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., weight: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., transfer: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., isolate: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class RouteRule(_message.Message):
    __slots__ = ["id", "name", "namespace", "enable", "routing_policy", "routing_config", "revision", "ctime", "mtime", "etime", "priority", "description", "extendInfo"]
    class ExtendInfoEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    ENABLE_FIELD_NUMBER: _ClassVar[int]
    ROUTING_POLICY_FIELD_NUMBER: _ClassVar[int]
    ROUTING_CONFIG_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    ETIME_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EXTENDINFO_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    namespace: str
    enable: bool
    routing_policy: RoutingPolicy
    routing_config: _any_pb2.Any
    revision: str
    ctime: str
    mtime: str
    etime: str
    priority: int
    description: str
    extendInfo: _containers.ScalarMap[str, str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., namespace: _Optional[str] = ..., enable: bool = ..., routing_policy: _Optional[_Union[RoutingPolicy, str]] = ..., routing_config: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., revision: _Optional[str] = ..., ctime: _Optional[str] = ..., mtime: _Optional[str] = ..., etime: _Optional[str] = ..., priority: _Optional[int] = ..., description: _Optional[str] = ..., extendInfo: _Optional[_Mapping[str, str]] = ...) -> None: ...

class MetadataFailover(_message.Message):
    __slots__ = ["failover_range", "labels"]
    class FailoverRange(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        ALL: _ClassVar[MetadataFailover.FailoverRange]
        OTHERS: _ClassVar[MetadataFailover.FailoverRange]
        OTHER_KEYS: _ClassVar[MetadataFailover.FailoverRange]
    ALL: MetadataFailover.FailoverRange
    OTHERS: MetadataFailover.FailoverRange
    OTHER_KEYS: MetadataFailover.FailoverRange
    class LabelsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    FAILOVER_RANGE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    failover_range: MetadataFailover.FailoverRange
    labels: _containers.ScalarMap[str, str]
    def __init__(self, failover_range: _Optional[_Union[MetadataFailover.FailoverRange, str]] = ..., labels: _Optional[_Mapping[str, str]] = ...) -> None: ...

class MetadataRoutingConfig(_message.Message):
    __slots__ = ["service", "namespace", "labels", "failover"]
    class LabelsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    FAILOVER_FIELD_NUMBER: _ClassVar[int]
    service: str
    namespace: str
    labels: _containers.ScalarMap[str, str]
    failover: MetadataFailover
    def __init__(self, service: _Optional[str] = ..., namespace: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ..., failover: _Optional[_Union[MetadataFailover, _Mapping]] = ...) -> None: ...

class RuleRoutingConfig(_message.Message):
    __slots__ = ["sources", "destinations", "rules"]
    SOURCES_FIELD_NUMBER: _ClassVar[int]
    DESTINATIONS_FIELD_NUMBER: _ClassVar[int]
    RULES_FIELD_NUMBER: _ClassVar[int]
    sources: _containers.RepeatedCompositeFieldContainer[SourceService]
    destinations: _containers.RepeatedCompositeFieldContainer[DestinationGroup]
    rules: _containers.RepeatedCompositeFieldContainer[SubRuleRouting]
    def __init__(self, sources: _Optional[_Iterable[_Union[SourceService, _Mapping]]] = ..., destinations: _Optional[_Iterable[_Union[DestinationGroup, _Mapping]]] = ..., rules: _Optional[_Iterable[_Union[SubRuleRouting, _Mapping]]] = ...) -> None: ...

class SubRuleRouting(_message.Message):
    __slots__ = ["name", "sources", "destinations"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SOURCES_FIELD_NUMBER: _ClassVar[int]
    DESTINATIONS_FIELD_NUMBER: _ClassVar[int]
    name: str
    sources: _containers.RepeatedCompositeFieldContainer[SourceService]
    destinations: _containers.RepeatedCompositeFieldContainer[DestinationGroup]
    def __init__(self, name: _Optional[str] = ..., sources: _Optional[_Iterable[_Union[SourceService, _Mapping]]] = ..., destinations: _Optional[_Iterable[_Union[DestinationGroup, _Mapping]]] = ...) -> None: ...

class SourceService(_message.Message):
    __slots__ = ["service", "namespace", "arguments"]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
    service: str
    namespace: str
    arguments: _containers.RepeatedCompositeFieldContainer[SourceMatch]
    def __init__(self, service: _Optional[str] = ..., namespace: _Optional[str] = ..., arguments: _Optional[_Iterable[_Union[SourceMatch, _Mapping]]] = ...) -> None: ...

class DestinationGroup(_message.Message):
    __slots__ = ["service", "namespace", "labels", "priority", "weight", "transfer", "isolate", "name"]
    class LabelsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _model_pb2.MatchString
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ...) -> None: ...
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_FIELD_NUMBER: _ClassVar[int]
    ISOLATE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    service: str
    namespace: str
    labels: _containers.MessageMap[str, _model_pb2.MatchString]
    priority: int
    weight: int
    transfer: str
    isolate: bool
    name: str
    def __init__(self, service: _Optional[str] = ..., namespace: _Optional[str] = ..., labels: _Optional[_Mapping[str, _model_pb2.MatchString]] = ..., priority: _Optional[int] = ..., weight: _Optional[int] = ..., transfer: _Optional[str] = ..., isolate: bool = ..., name: _Optional[str] = ...) -> None: ...

class SourceMatch(_message.Message):
    __slots__ = ["type", "key", "value"]
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        CUSTOM: _ClassVar[SourceMatch.Type]
        METHOD: _ClassVar[SourceMatch.Type]
        HEADER: _ClassVar[SourceMatch.Type]
        QUERY: _ClassVar[SourceMatch.Type]
        CALLER_IP: _ClassVar[SourceMatch.Type]
        PATH: _ClassVar[SourceMatch.Type]
        COOKIE: _ClassVar[SourceMatch.Type]
    CUSTOM: SourceMatch.Type
    METHOD: SourceMatch.Type
    HEADER: SourceMatch.Type
    QUERY: SourceMatch.Type
    CALLER_IP: SourceMatch.Type
    PATH: SourceMatch.Type
    COOKIE: SourceMatch.Type
    TYPE_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    type: SourceMatch.Type
    key: str
    value: _model_pb2.MatchString
    def __init__(self, type: _Optional[_Union[SourceMatch.Type, str]] = ..., key: _Optional[str] = ..., value: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ...) -> None: ...



from google.protobuf import wrappers_pb2 as _wrappers_pb2
from ..model import model_pb2 as _model_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Client(_message.Message):
    __slots__ = ["host", "type", "version", "location", "id", "stat", "ctime", "mtime"]
    class ClientType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNKNOWN: _ClassVar[Client.ClientType]
        SDK: _ClassVar[Client.ClientType]
        AGENT: _ClassVar[Client.ClientType]
    UNKNOWN: Client.ClientType
    SDK: Client.ClientType
    AGENT: Client.ClientType
    HOST_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    STAT_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    host: _wrappers_pb2.StringValue
    type: Client.ClientType
    version: _wrappers_pb2.StringValue
    location: _model_pb2.Location
    id: _wrappers_pb2.StringValue
    stat: _containers.RepeatedCompositeFieldContainer[StatInfo]
    ctime: _wrappers_pb2.StringValue
    mtime: _wrappers_pb2.StringValue
    def __init__(self, host: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., type: _Optional[_Union[Client.ClientType, str]] = ..., version: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., location: _Optional[_Union[_model_pb2.Location, _Mapping]] = ..., id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., stat: _Optional[_Iterable[_Union[StatInfo, _Mapping]]] = ..., ctime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., mtime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class StatInfo(_message.Message):
    __slots__ = ["target", "port", "path", "protocol"]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    target: _wrappers_pb2.StringValue
    port: _wrappers_pb2.UInt32Value
    path: _wrappers_pb2.StringValue
    protocol: _wrappers_pb2.StringValue
    def __init__(self, target: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., port: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., path: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., protocol: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...



from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf import any_pb2 as _any_pb2
from ..model import namespace_pb2 as _namespace_pb2
from ..service_manage import service_pb2 as _service_pb2
from ..traffic_manage import routing_pb2 as _routing_pb2
from ..traffic_manage import ratelimit_pb2 as _ratelimit_pb2
from ..fault_tolerance import circuitbreaker_pb2 as _circuitbreaker_pb2
from ..model import model_pb2 as _model_pb2
from ..service_manage import client_pb2 as _client_pb2
from ..service_manage import configrelease_pb2 as _configrelease_pb2
from ..fault_tolerance import fault_detector_pb2 as _fault_detector_pb2
from ..security import auth_pb2 as _auth_pb2
from ..service_manage import contract_pb2 as _contract_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Response(_message.Message):
    __slots__ = ["code", "info", "client", "namespace", "service", "instance", "routing", "alias", "rateLimit", "circuitBreaker", "configRelease", "user", "userGroup", "authStrategy", "relation", "loginResponse", "modifyAuthStrategy", "modifyUserGroup", "resources", "optionSwitch", "instanceLabels", "data"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    INSTANCE_FIELD_NUMBER: _ClassVar[int]
    ROUTING_FIELD_NUMBER: _ClassVar[int]
    ALIAS_FIELD_NUMBER: _ClassVar[int]
    RATELIMIT_FIELD_NUMBER: _ClassVar[int]
    CIRCUITBREAKER_FIELD_NUMBER: _ClassVar[int]
    CONFIGRELEASE_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    USERGROUP_FIELD_NUMBER: _ClassVar[int]
    AUTHSTRATEGY_FIELD_NUMBER: _ClassVar[int]
    RELATION_FIELD_NUMBER: _ClassVar[int]
    LOGINRESPONSE_FIELD_NUMBER: _ClassVar[int]
    MODIFYAUTHSTRATEGY_FIELD_NUMBER: _ClassVar[int]
    MODIFYUSERGROUP_FIELD_NUMBER: _ClassVar[int]
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    OPTIONSWITCH_FIELD_NUMBER: _ClassVar[int]
    INSTANCELABELS_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    code: _wrappers_pb2.UInt32Value
    info: _wrappers_pb2.StringValue
    client: _client_pb2.Client
    namespace: _namespace_pb2.Namespace
    service: _service_pb2.Service
    instance: _service_pb2.Instance
    routing: _routing_pb2.Routing
    alias: _service_pb2.ServiceAlias
    rateLimit: _ratelimit_pb2.Rule
    circuitBreaker: _circuitbreaker_pb2.CircuitBreaker
    configRelease: _configrelease_pb2.ConfigRelease
    user: _auth_pb2.User
    userGroup: _auth_pb2.UserGroup
    authStrategy: _auth_pb2.AuthStrategy
    relation: _auth_pb2.UserGroupRelation
    loginResponse: _auth_pb2.LoginResponse
    modifyAuthStrategy: _auth_pb2.ModifyAuthStrategy
    modifyUserGroup: _auth_pb2.ModifyUserGroup
    resources: _auth_pb2.StrategyResources
    optionSwitch: OptionSwitch
    instanceLabels: InstanceLabels
    data: _any_pb2.Any
    def __init__(self, code: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., info: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., client: _Optional[_Union[_client_pb2.Client, _Mapping]] = ..., namespace: _Optional[_Union[_namespace_pb2.Namespace, _Mapping]] = ..., service: _Optional[_Union[_service_pb2.Service, _Mapping]] = ..., instance: _Optional[_Union[_service_pb2.Instance, _Mapping]] = ..., routing: _Optional[_Union[_routing_pb2.Routing, _Mapping]] = ..., alias: _Optional[_Union[_service_pb2.ServiceAlias, _Mapping]] = ..., rateLimit: _Optional[_Union[_ratelimit_pb2.Rule, _Mapping]] = ..., circuitBreaker: _Optional[_Union[_circuitbreaker_pb2.CircuitBreaker, _Mapping]] = ..., configRelease: _Optional[_Union[_configrelease_pb2.ConfigRelease, _Mapping]] = ..., user: _Optional[_Union[_auth_pb2.User, _Mapping]] = ..., userGroup: _Optional[_Union[_auth_pb2.UserGroup, _Mapping]] = ..., authStrategy: _Optional[_Union[_auth_pb2.AuthStrategy, _Mapping]] = ..., relation: _Optional[_Union[_auth_pb2.UserGroupRelation, _Mapping]] = ..., loginResponse: _Optional[_Union[_auth_pb2.LoginResponse, _Mapping]] = ..., modifyAuthStrategy: _Optional[_Union[_auth_pb2.ModifyAuthStrategy, _Mapping]] = ..., modifyUserGroup: _Optional[_Union[_auth_pb2.ModifyUserGroup, _Mapping]] = ..., resources: _Optional[_Union[_auth_pb2.StrategyResources, _Mapping]] = ..., optionSwitch: _Optional[_Union[OptionSwitch, _Mapping]] = ..., instanceLabels: _Optional[_Union[InstanceLabels, _Mapping]] = ..., data: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class BatchWriteResponse(_message.Message):
    __slots__ = ["code", "info", "size", "responses"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    RESPONSES_FIELD_NUMBER: _ClassVar[int]
    code: _wrappers_pb2.UInt32Value
    info: _wrappers_pb2.StringValue
    size: _wrappers_pb2.UInt32Value
    responses: _containers.RepeatedCompositeFieldContainer[Response]
    def __init__(self, code: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., info: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., size: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., responses: _Optional[_Iterable[_Union[Response, _Mapping]]] = ...) -> None: ...

class BatchQueryResponse(_message.Message):
    __slots__ = ["code", "info", "amount", "size", "namespaces", "services", "instances", "routings", "aliases", "rateLimits", "configWithServices", "users", "userGroups", "authStrategies", "clients", "data", "summary"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACES_FIELD_NUMBER: _ClassVar[int]
    SERVICES_FIELD_NUMBER: _ClassVar[int]
    INSTANCES_FIELD_NUMBER: _ClassVar[int]
    ROUTINGS_FIELD_NUMBER: _ClassVar[int]
    ALIASES_FIELD_NUMBER: _ClassVar[int]
    RATELIMITS_FIELD_NUMBER: _ClassVar[int]
    CONFIGWITHSERVICES_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    USERGROUPS_FIELD_NUMBER: _ClassVar[int]
    AUTHSTRATEGIES_FIELD_NUMBER: _ClassVar[int]
    CLIENTS_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    code: _wrappers_pb2.UInt32Value
    info: _wrappers_pb2.StringValue
    amount: _wrappers_pb2.UInt32Value
    size: _wrappers_pb2.UInt32Value
    namespaces: _containers.RepeatedCompositeFieldContainer[_namespace_pb2.Namespace]
    services: _containers.RepeatedCompositeFieldContainer[_service_pb2.Service]
    instances: _containers.RepeatedCompositeFieldContainer[_service_pb2.Instance]
    routings: _containers.RepeatedCompositeFieldContainer[_routing_pb2.Routing]
    aliases: _containers.RepeatedCompositeFieldContainer[_service_pb2.ServiceAlias]
    rateLimits: _containers.RepeatedCompositeFieldContainer[_ratelimit_pb2.Rule]
    configWithServices: _containers.RepeatedCompositeFieldContainer[_configrelease_pb2.ConfigWithService]
    users: _containers.RepeatedCompositeFieldContainer[_auth_pb2.User]
    userGroups: _containers.RepeatedCompositeFieldContainer[_auth_pb2.UserGroup]
    authStrategies: _containers.RepeatedCompositeFieldContainer[_auth_pb2.AuthStrategy]
    clients: _containers.RepeatedCompositeFieldContainer[_client_pb2.Client]
    data: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    summary: _model_pb2.Summary
    def __init__(self, code: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., info: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., amount: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., size: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., namespaces: _Optional[_Iterable[_Union[_namespace_pb2.Namespace, _Mapping]]] = ..., services: _Optional[_Iterable[_Union[_service_pb2.Service, _Mapping]]] = ..., instances: _Optional[_Iterable[_Union[_service_pb2.Instance, _Mapping]]] = ..., routings: _Optional[_Iterable[_Union[_routing_pb2.Routing, _Mapping]]] = ..., aliases: _Optional[_Iterable[_Union[_service_pb2.ServiceAlias, _Mapping]]] = ..., rateLimits: _Optional[_Iterable[_Union[_ratelimit_pb2.Rule, _Mapping]]] = ..., configWithServices: _Optional[_Iterable[_Union[_configrelease_pb2.ConfigWithService, _Mapping]]] = ..., users: _Optional[_Iterable[_Union[_auth_pb2.User, _Mapping]]] = ..., userGroups: _Optional[_Iterable[_Union[_auth_pb2.UserGroup, _Mapping]]] = ..., authStrategies: _Optional[_Iterable[_Union[_auth_pb2.AuthStrategy, _Mapping]]] = ..., clients: _Optional[_Iterable[_Union[_client_pb2.Client, _Mapping]]] = ..., data: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ..., summary: _Optional[_Union[_model_pb2.Summary, _Mapping]] = ...) -> None: ...

class DiscoverResponse(_message.Message):
    __slots__ = ["code", "info", "type", "service", "instances", "routing", "rateLimit", "circuitBreaker", "services", "namespaces", "faultDetector", "aliasFor", "serviceContract"]
    class DiscoverResponseType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNKNOWN: _ClassVar[DiscoverResponse.DiscoverResponseType]
        INSTANCE: _ClassVar[DiscoverResponse.DiscoverResponseType]
        CLUSTER: _ClassVar[DiscoverResponse.DiscoverResponseType]
        ROUTING: _ClassVar[DiscoverResponse.DiscoverResponseType]
        RATE_LIMIT: _ClassVar[DiscoverResponse.DiscoverResponseType]
        CIRCUIT_BREAKER: _ClassVar[DiscoverResponse.DiscoverResponseType]
        SERVICES: _ClassVar[DiscoverResponse.DiscoverResponseType]
        NAMESPACES: _ClassVar[DiscoverResponse.DiscoverResponseType]
        FAULT_DETECTOR: _ClassVar[DiscoverResponse.DiscoverResponseType]
        SERVICE_CONTRACT: _ClassVar[DiscoverResponse.DiscoverResponseType]
    UNKNOWN: DiscoverResponse.DiscoverResponseType
    INSTANCE: DiscoverResponse.DiscoverResponseType
    CLUSTER: DiscoverResponse.DiscoverResponseType
    ROUTING: DiscoverResponse.DiscoverResponseType
    RATE_LIMIT: DiscoverResponse.DiscoverResponseType
    CIRCUIT_BREAKER: DiscoverResponse.DiscoverResponseType
    SERVICES: DiscoverResponse.DiscoverResponseType
    NAMESPACES: DiscoverResponse.DiscoverResponseType
    FAULT_DETECTOR: DiscoverResponse.DiscoverResponseType
    SERVICE_CONTRACT: DiscoverResponse.DiscoverResponseType
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    INSTANCES_FIELD_NUMBER: _ClassVar[int]
    ROUTING_FIELD_NUMBER: _ClassVar[int]
    RATELIMIT_FIELD_NUMBER: _ClassVar[int]
    CIRCUITBREAKER_FIELD_NUMBER: _ClassVar[int]
    SERVICES_FIELD_NUMBER: _ClassVar[int]
    NAMESPACES_FIELD_NUMBER: _ClassVar[int]
    FAULTDETECTOR_FIELD_NUMBER: _ClassVar[int]
    ALIASFOR_FIELD_NUMBER: _ClassVar[int]
    SERVICECONTRACT_FIELD_NUMBER: _ClassVar[int]
    code: _wrappers_pb2.UInt32Value
    info: _wrappers_pb2.StringValue
    type: DiscoverResponse.DiscoverResponseType
    service: _service_pb2.Service
    instances: _containers.RepeatedCompositeFieldContainer[_service_pb2.Instance]
    routing: _routing_pb2.Routing
    rateLimit: _ratelimit_pb2.RateLimit
    circuitBreaker: _circuitbreaker_pb2.CircuitBreaker
    services: _containers.RepeatedCompositeFieldContainer[_service_pb2.Service]
    namespaces: _containers.RepeatedCompositeFieldContainer[_namespace_pb2.Namespace]
    faultDetector: _fault_detector_pb2.FaultDetector
    aliasFor: _service_pb2.Service
    serviceContract: _contract_pb2.ServiceContract
    def __init__(self, code: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., info: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., type: _Optional[_Union[DiscoverResponse.DiscoverResponseType, str]] = ..., service: _Optional[_Union[_service_pb2.Service, _Mapping]] = ..., instances: _Optional[_Iterable[_Union[_service_pb2.Instance, _Mapping]]] = ..., routing: _Optional[_Union[_routing_pb2.Routing, _Mapping]] = ..., rateLimit: _Optional[_Union[_ratelimit_pb2.RateLimit, _Mapping]] = ..., circuitBreaker: _Optional[_Union[_circuitbreaker_pb2.CircuitBreaker, _Mapping]] = ..., services: _Optional[_Iterable[_Union[_service_pb2.Service, _Mapping]]] = ..., namespaces: _Optional[_Iterable[_Union[_namespace_pb2.Namespace, _Mapping]]] = ..., faultDetector: _Optional[_Union[_fault_detector_pb2.FaultDetector, _Mapping]] = ..., aliasFor: _Optional[_Union[_service_pb2.Service, _Mapping]] = ..., serviceContract: _Optional[_Union[_contract_pb2.ServiceContract, _Mapping]] = ...) -> None: ...

class OptionSwitch(_message.Message):
    __slots__ = ["options"]
    class OptionsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    options: _containers.ScalarMap[str, str]
    def __init__(self, options: _Optional[_Mapping[str, str]] = ...) -> None: ...

class InstanceLabels(_message.Message):
    __slots__ = ["labels"]
    class LabelsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _model_pb2.StringList
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_model_pb2.StringList, _Mapping]] = ...) -> None: ...
    LABELS_FIELD_NUMBER: _ClassVar[int]
    labels: _containers.MessageMap[str, _model_pb2.StringList]
    def __init__(self, labels: _Optional[_Mapping[str, _model_pb2.StringList]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: routing.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ..model import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rrouting.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x19google/protobuf/any.proto\x1a\x0bmodel.proto\"\x96\x03\n\x07Routing\x12-\n\x07service\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1b\n\x08inbounds\x18\x03 \x03(\x0b\x32\t.v1.Route\x12\x1c\n\toutbounds\x18\x04 \x03(\x0b\x32\t.v1.Route\x12+\n\x05\x63time\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08revision\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x42\n\rservice_token\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rservice_token\x12\x1c\n\x05rules\x18\x15 \x03(\x0b\x32\r.v1.RouteRuleJ\x04\x08\t\x10\x15\"\xad\x01\n\x05Route\x12\x1b\n\x07sources\x18\x01 \x03(\x0b\x32\n.v1.Source\x12%\n\x0c\x64\x65stinations\x18\x02 \x03(\x0b\x32\x0f.v1.Destination\x12-\n\nextendInfo\x18\x03 \x03(\x0b\x32\x19.v1.Route.ExtendInfoEntry\x1a\x31\n\x0f\x45xtendInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd6\x01\n\x06Source\x12-\n\x07service\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x08metadata\x18\x03 \x03(\x0b\x32\x18.v1.Source.MetadataEntry\x1a@\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchString:\x02\x38\x01\"\xc7\x03\n\x0b\x44\x65stination\x12-\n\x07service\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\x08metadata\x18\x03 \x03(\x0b\x32\x1d.v1.Destination.MetadataEntry\x12.\n\x08priority\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12,\n\x06weight\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12.\n\x08transfer\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x07isolate\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x04name\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x1a@\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchString:\x02\x38\x01\"\x8d\x03\n\tRouteRule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0e\n\x06\x65nable\x18\x04 \x01(\x08\x12\x39\n\x0erouting_policy\x18\x05 \x01(\x0e\x32\x11.v1.RoutingPolicyR\x0erouting_policy\x12<\n\x0erouting_config\x18\x06 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0erouting_config\x12\x10\n\x08revision\x18\x07 \x01(\t\x12\r\n\x05\x63time\x18\x08 \x01(\t\x12\r\n\x05mtime\x18\t \x01(\t\x12\r\n\x05\x65time\x18\n \x01(\t\x12\x10\n\x08priority\x18\x0b \x01(\r\x12\x13\n\x0b\x64\x65scription\x18\x0c \x01(\t\x12\x31\n\nextendInfo\x18\x14 \x03(\x0b\x32\x1d.v1.RouteRule.ExtendInfoEntry\x1a\x31\n\x0f\x45xtendInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe5\x01\n\x10MetadataFailover\x12:\n\x0e\x66\x61ilover_range\x18\x01 \x01(\x0e\x32\".v1.MetadataFailover.FailoverRange\x12\x30\n\x06labels\x18\x02 \x03(\x0b\x32 .v1.MetadataFailover.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\rFailoverRange\x12\x07\n\x03\x41LL\x10\x00\x12\n\n\x06OTHERS\x10\x01\x12\x0e\n\nOTHER_KEYS\x10\x02\"\xc9\x01\n\x15MetadataRoutingConfig\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x35\n\x06labels\x18\x03 \x03(\x0b\x32%.v1.MetadataRoutingConfig.LabelsEntry\x12&\n\x08\x66\x61ilover\x18\x04 \x01(\x0b\x32\x14.v1.MetadataFailover\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x11RuleRoutingConfig\x12\"\n\x07sources\x18\x01 \x03(\x0b\x32\x11.v1.SourceService\x12*\n\x0c\x64\x65stinations\x18\x02 \x03(\x0b\x32\x14.v1.DestinationGroup\x12!\n\x05rules\x18\x03 \x03(\x0b\x32\x12.v1.SubRuleRouting\"n\n\x0eSubRuleRouting\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\x07sources\x18\x02 \x03(\x0b\x32\x11.v1.SourceService\x12*\n\x0c\x64\x65stinations\x18\x03 \x03(\x0b\x32\x14.v1.DestinationGroup\"W\n\rSourceService\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\"\n\targuments\x18\x03 \x03(\x0b\x32\x0f.v1.SourceMatch\"\xfb\x01\n\x10\x44\x65stinationGroup\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x30\n\x06labels\x18\x03 \x03(\x0b\x32 .v1.DestinationGroup.LabelsEntry\x12\x10\n\x08priority\x18\x04 \x01(\r\x12\x0e\n\x06weight\x18\x05 \x01(\r\x12\x10\n\x08transfer\x18\x06 \x01(\t\x12\x0f\n\x07isolate\x18\x07 \x01(\x08\x12\x0c\n\x04name\x18\x08 \x01(\t\x1a>\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchString:\x02\x38\x01\"\xba\x01\n\x0bSourceMatch\x12\"\n\x04type\x18\x01 \x01(\x0e\x32\x14.v1.SourceMatch.Type\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x1e\n\x05value\x18\x03 \x01(\x0b\x32\x0f.v1.MatchString\"Z\n\x04Type\x12\n\n\x06\x43USTOM\x10\x00\x12\n\n\x06METHOD\x10\x01\x12\n\n\x06HEADER\x10\x02\x12\t\n\x05QUERY\x10\x03\x12\r\n\tCALLER_IP\x10\x04\x12\x08\n\x04PATH\x10\x05\x12\n\n\x06\x43OOKIE\x10\x06*3\n\rRoutingPolicy\x12\x0e\n\nRulePolicy\x10\x00\x12\x12\n\x0eMetadataPolicy\x10\x01\x42\x8d\x01\n7com.tencent.polaris.specification.api.v1.traffic.manageB\x0cRoutingProtoZDgithub.com/polarismesh/specification/source/go/api/v1/traffic_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'routing_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.traffic.manageB\014RoutingProtoZDgithub.com/polarismesh/specification/source/go/api/v1/traffic_manage'
  _ROUTE_EXTENDINFOENTRY._options = None
  _ROUTE_EXTENDINFOENTRY._serialized_options = b'8\001'
  _SOURCE_METADATAENTRY._options = None
  _SOURCE_METADATAENTRY._serialized_options = b'8\001'
  _DESTINATION_METADATAENTRY._options = None
  _DESTINATION_METADATAENTRY._serialized_options = b'8\001'
  _ROUTERULE_EXTENDINFOENTRY._options = None
  _ROUTERULE_EXTENDINFOENTRY._serialized_options = b'8\001'
  _METADATAFAILOVER_LABELSENTRY._options = None
  _METADATAFAILOVER_LABELSENTRY._serialized_options = b'8\001'
  _METADATAROUTINGCONFIG_LABELSENTRY._options = None
  _METADATAROUTINGCONFIG_LABELSENTRY._serialized_options = b'8\001'
  _DESTINATIONGROUP_LABELSENTRY._options = None
  _DESTINATIONGROUP_LABELSENTRY._serialized_options = b'8\001'
  _globals['_ROUTINGPOLICY']._serialized_start=2970
  _globals['_ROUTINGPOLICY']._serialized_end=3021
  _globals['_ROUTING']._serialized_start=94
  _globals['_ROUTING']._serialized_end=500
  _globals['_ROUTE']._serialized_start=503
  _globals['_ROUTE']._serialized_end=676
  _globals['_ROUTE_EXTENDINFOENTRY']._serialized_start=627
  _globals['_ROUTE_EXTENDINFOENTRY']._serialized_end=676
  _globals['_SOURCE']._serialized_start=679
  _globals['_SOURCE']._serialized_end=893
  _globals['_SOURCE_METADATAENTRY']._serialized_start=829
  _globals['_SOURCE_METADATAENTRY']._serialized_end=893
  _globals['_DESTINATION']._serialized_start=896
  _globals['_DESTINATION']._serialized_end=1351
  _globals['_DESTINATION_METADATAENTRY']._serialized_start=829
  _globals['_DESTINATION_METADATAENTRY']._serialized_end=893
  _globals['_ROUTERULE']._serialized_start=1354
  _globals['_ROUTERULE']._serialized_end=1751
  _globals['_ROUTERULE_EXTENDINFOENTRY']._serialized_start=627
  _globals['_ROUTERULE_EXTENDINFOENTRY']._serialized_end=676
  _globals['_METADATAFAILOVER']._serialized_start=1754
  _globals['_METADATAFAILOVER']._serialized_end=1983
  _globals['_METADATAFAILOVER_LABELSENTRY']._serialized_start=1884
  _globals['_METADATAFAILOVER_LABELSENTRY']._serialized_end=1929
  _globals['_METADATAFAILOVER_FAILOVERRANGE']._serialized_start=1931
  _globals['_METADATAFAILOVER_FAILOVERRANGE']._serialized_end=1983
  _globals['_METADATAROUTINGCONFIG']._serialized_start=1986
  _globals['_METADATAROUTINGCONFIG']._serialized_end=2187
  _globals['_METADATAROUTINGCONFIG_LABELSENTRY']._serialized_start=1884
  _globals['_METADATAROUTINGCONFIG_LABELSENTRY']._serialized_end=1929
  _globals['_RULEROUTINGCONFIG']._serialized_start=2190
  _globals['_RULEROUTINGCONFIG']._serialized_end=2324
  _globals['_SUBRULEROUTING']._serialized_start=2326
  _globals['_SUBRULEROUTING']._serialized_end=2436
  _globals['_SOURCESERVICE']._serialized_start=2438
  _globals['_SOURCESERVICE']._serialized_end=2525
  _globals['_DESTINATIONGROUP']._serialized_start=2528
  _globals['_DESTINATIONGROUP']._serialized_end=2779
  _globals['_DESTINATIONGROUP_LABELSENTRY']._serialized_start=2717
  _globals['_DESTINATIONGROUP_LABELSENTRY']._serialized_end=2779
  _globals['_SOURCEMATCH']._serialized_start=2782
  _globals['_SOURCEMATCH']._serialized_end=2968
  _globals['_SOURCEMATCH_TYPE']._serialized_start=2878
  _globals['_SOURCEMATCH_TYPE']._serialized_end=2968
# @@protoc_insertion_point(module_scope)



from ..model import model_pb2 as _model_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FaultDetector(_message.Message):
    __slots__ = ["rules", "revision"]
    RULES_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    rules: _containers.RepeatedCompositeFieldContainer[FaultDetectRule]
    revision: str
    def __init__(self, rules: _Optional[_Iterable[_Union[FaultDetectRule, _Mapping]]] = ..., revision: _Optional[str] = ...) -> None: ...

class FaultDetectRule(_message.Message):
    __slots__ = ["id", "name", "namespace", "revision", "ctime", "mtime", "description", "target_service", "interval", "timeout", "port", "protocol", "http_config", "tcp_config", "udp_config"]
    class Protocol(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNKNOWN: _ClassVar[FaultDetectRule.Protocol]
        HTTP: _ClassVar[FaultDetectRule.Protocol]
        TCP: _ClassVar[FaultDetectRule.Protocol]
        UDP: _ClassVar[FaultDetectRule.Protocol]
    UNKNOWN: FaultDetectRule.Protocol
    HTTP: FaultDetectRule.Protocol
    TCP: FaultDetectRule.Protocol
    UDP: FaultDetectRule.Protocol
    class DestinationService(_message.Message):
        __slots__ = ["service", "namespace", "method"]
        SERVICE_FIELD_NUMBER: _ClassVar[int]
        NAMESPACE_FIELD_NUMBER: _ClassVar[int]
        METHOD_FIELD_NUMBER: _ClassVar[int]
        service: str
        namespace: str
        method: _model_pb2.MatchString
        def __init__(self, service: _Optional[str] = ..., namespace: _Optional[str] = ..., method: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TARGET_SERVICE_FIELD_NUMBER: _ClassVar[int]
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    HTTP_CONFIG_FIELD_NUMBER: _ClassVar[int]
    TCP_CONFIG_FIELD_NUMBER: _ClassVar[int]
    UDP_CONFIG_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    namespace: str
    revision: str
    ctime: str
    mtime: str
    description: str
    target_service: FaultDetectRule.DestinationService
    interval: int
    timeout: int
    port: int
    protocol: FaultDetectRule.Protocol
    http_config: HttpProtocolConfig
    tcp_config: TcpProtocolConfig
    udp_config: UdpProtocolConfig
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., namespace: _Optional[str] = ..., revision: _Optional[str] = ..., ctime: _Optional[str] = ..., mtime: _Optional[str] = ..., description: _Optional[str] = ..., target_service: _Optional[_Union[FaultDetectRule.DestinationService, _Mapping]] = ..., interval: _Optional[int] = ..., timeout: _Optional[int] = ..., port: _Optional[int] = ..., protocol: _Optional[_Union[FaultDetectRule.Protocol, str]] = ..., http_config: _Optional[_Union[HttpProtocolConfig, _Mapping]] = ..., tcp_config: _Optional[_Union[TcpProtocolConfig, _Mapping]] = ..., udp_config: _Optional[_Union[UdpProtocolConfig, _Mapping]] = ...) -> None: ...

class HttpProtocolConfig(_message.Message):
    __slots__ = ["method", "url", "headers", "body"]
    class MessageHeader(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    METHOD_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    HEADERS_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    method: str
    url: str
    headers: _containers.RepeatedCompositeFieldContainer[HttpProtocolConfig.MessageHeader]
    body: str
    def __init__(self, method: _Optional[str] = ..., url: _Optional[str] = ..., headers: _Optional[_Iterable[_Union[HttpProtocolConfig.MessageHeader, _Mapping]]] = ..., body: _Optional[str] = ...) -> None: ...

class TcpProtocolConfig(_message.Message):
    __slots__ = ["send", "receive"]
    SEND_FIELD_NUMBER: _ClassVar[int]
    RECEIVE_FIELD_NUMBER: _ClassVar[int]
    send: str
    receive: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, send: _Optional[str] = ..., receive: _Optional[_Iterable[str]] = ...) -> None: ...

class UdpProtocolConfig(_message.Message):
    __slots__ = ["send", "receive"]
    SEND_FIELD_NUMBER: _ClassVar[int]
    RECEIVE_FIELD_NUMBER: _ClassVar[int]
    send: str
    receive: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, send: _Optional[str] = ..., receive: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ..model import namespace_pb2 as namespace__pb2
from ..service_manage import service_pb2 as service__pb2
from ..traffic_manage import routing_pb2 as routing__pb2
from ..traffic_manage import ratelimit_pb2 as ratelimit__pb2
from ..fault_tolerance import circuitbreaker_pb2 as circuitbreaker__pb2
from ..model import model_pb2 as model__pb2
from ..service_manage import client_pb2 as client__pb2
from ..service_manage import configrelease_pb2 as configrelease__pb2
from ..fault_tolerance import fault_detector_pb2 as fault__detector__pb2
from ..security import auth_pb2 as auth__pb2
from ..service_manage import contract_pb2 as contract__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eresponse.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x19google/protobuf/any.proto\x1a\x0fnamespace.proto\x1a\rservice.proto\x1a\rrouting.proto\x1a\x0fratelimit.proto\x1a\x14\x63ircuitbreaker.proto\x1a\x0bmodel.proto\x1a\x0c\x63lient.proto\x1a\x13\x63onfigrelease.proto\x1a\x14\x66\x61ult_detector.proto\x1a\nauth.proto\x1a\x0e\x63ontract.proto\"\xcf\x06\n\x08Response\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1a\n\x06\x63lient\x18\x03 \x01(\x0b\x32\n.v1.Client\x12 \n\tnamespace\x18\x04 \x01(\x0b\x32\r.v1.Namespace\x12\x1c\n\x07service\x18\x05 \x01(\x0b\x32\x0b.v1.Service\x12\x1e\n\x08instance\x18\x06 \x01(\x0b\x32\x0c.v1.Instance\x12\x1c\n\x07routing\x18\x07 \x01(\x0b\x32\x0b.v1.Routing\x12\x1f\n\x05\x61lias\x18\x08 \x01(\x0b\x32\x10.v1.ServiceAlias\x12\x1b\n\trateLimit\x18\t \x01(\x0b\x32\x08.v1.Rule\x12*\n\x0e\x63ircuitBreaker\x18\n \x01(\x0b\x32\x12.v1.CircuitBreaker\x12(\n\rconfigRelease\x18\x0b \x01(\x0b\x32\x11.v1.ConfigRelease\x12\x16\n\x04user\x18\x13 \x01(\x0b\x32\x08.v1.User\x12 \n\tuserGroup\x18\x14 \x01(\x0b\x32\r.v1.UserGroup\x12&\n\x0c\x61uthStrategy\x18\x15 \x01(\x0b\x32\x10.v1.AuthStrategy\x12\'\n\x08relation\x18\x16 \x01(\x0b\x32\x15.v1.UserGroupRelation\x12(\n\rloginResponse\x18\x17 \x01(\x0b\x32\x11.v1.LoginResponse\x12\x32\n\x12modifyAuthStrategy\x18\x18 \x01(\x0b\x32\x16.v1.ModifyAuthStrategy\x12,\n\x0fmodifyUserGroup\x18\x19 \x01(\x0b\x32\x13.v1.ModifyUserGroup\x12(\n\tresources\x18\x1a \x01(\x0b\x32\x15.v1.StrategyResources\x12&\n\x0coptionSwitch\x18\x1b \x01(\x0b\x32\x10.v1.OptionSwitch\x12*\n\x0einstanceLabels\x18\x1c \x01(\x0b\x32\x12.v1.InstanceLabels\x12\"\n\x04\x64\x61ta\x18\x1d \x01(\x0b\x32\x14.google.protobuf.AnyJ\x04\x08\x0c\x10\x13\"\xb9\x01\n\x12\x42\x61tchWriteResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04size\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x1f\n\tresponses\x18\x04 \x03(\x0b\x32\x0c.v1.Response\"\x87\x05\n\x12\x42\x61tchQueryResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12!\n\nnamespaces\x18\x05 \x03(\x0b\x32\r.v1.Namespace\x12\x1d\n\x08services\x18\x06 \x03(\x0b\x32\x0b.v1.Service\x12\x1f\n\tinstances\x18\x07 \x03(\x0b\x32\x0c.v1.Instance\x12\x1d\n\x08routings\x18\x08 \x03(\x0b\x32\x0b.v1.Routing\x12!\n\x07\x61liases\x18\t \x03(\x0b\x32\x10.v1.ServiceAlias\x12\x1c\n\nrateLimits\x18\n \x03(\x0b\x32\x08.v1.Rule\x12\x31\n\x12\x63onfigWithServices\x18\x0b \x03(\x0b\x32\x15.v1.ConfigWithService\x12\x17\n\x05users\x18\x12 \x03(\x0b\x32\x08.v1.User\x12!\n\nuserGroups\x18\x13 \x03(\x0b\x32\r.v1.UserGroup\x12(\n\x0e\x61uthStrategies\x18\x14 \x03(\x0b\x32\x10.v1.AuthStrategy\x12\x1b\n\x07\x63lients\x18\x15 \x03(\x0b\x32\n.v1.Client\x12\"\n\x04\x64\x61ta\x18\x16 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x1c\n\x07summary\x18\x17 \x01(\x0b\x32\x0b.v1.SummaryJ\x04\x08\x0c\x10\x12\"\x88\x06\n\x10\x44iscoverResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x04type\x18\x03 \x01(\x0e\x32).v1.DiscoverResponse.DiscoverResponseType\x12\x1c\n\x07service\x18\x04 \x01(\x0b\x32\x0b.v1.Service\x12\x1f\n\tinstances\x18\x05 \x03(\x0b\x32\x0c.v1.Instance\x12\x1c\n\x07routing\x18\x06 \x01(\x0b\x32\x0b.v1.Routing\x12 \n\trateLimit\x18\x07 \x01(\x0b\x32\r.v1.RateLimit\x12*\n\x0e\x63ircuitBreaker\x18\x08 \x01(\x0b\x32\x12.v1.CircuitBreaker\x12\x1d\n\x08services\x18\t \x03(\x0b\x32\x0b.v1.Service\x12!\n\nnamespaces\x18\n \x03(\x0b\x32\r.v1.Namespace\x12(\n\rfaultDetector\x18\x0b \x01(\x0b\x32\x11.v1.FaultDetector\x12\x1d\n\x08\x61liasFor\x18\x15 \x01(\x0b\x32\x0b.v1.Service\x12,\n\x0fserviceContract\x18\x16 \x01(\x0b\x32\x13.v1.ServiceContract\"\xf8\x01\n\x14\x44iscoverResponseType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08INSTANCE\x10\x01\x12\x0b\n\x07\x43LUSTER\x10\x02\x12\x0b\n\x07ROUTING\x10\x03\x12\x0e\n\nRATE_LIMIT\x10\x04\x12\x13\n\x0f\x43IRCUIT_BREAKER\x10\x05\x12\x0c\n\x08SERVICES\x10\x06\x12\x0e\n\nNAMESPACES\x10\x0c\x12\x12\n\x0e\x46\x41ULT_DETECTOR\x10\r\x12\x14\n\x10SERVICE_CONTRACT\x10\x0e\"\x04\x08\x07\x10\x0b*\x04MESH*\x0bMESH_CONFIG*\x0e\x46LUX_DBREFRESH*\x08\x46LUX_SDK*\x0b\x46LUX_SERVERJ\x04\x08\x0c\x10\x15\"n\n\x0cOptionSwitch\x12.\n\x07options\x18\x01 \x03(\x0b\x32\x1d.v1.OptionSwitch.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x7f\n\x0eInstanceLabels\x12.\n\x06labels\x18\x01 \x03(\x0b\x32\x1e.v1.InstanceLabels.LabelsEntry\x1a=\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.v1.StringList:\x02\x38\x01\x42\x8e\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\rResponseProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\rResponseProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _OPTIONSWITCH_OPTIONSENTRY._options = None
  _OPTIONSWITCH_OPTIONSENTRY._serialized_options = b'8\001'
  _INSTANCELABELS_LABELSENTRY._options = None
  _INSTANCELABELS_LABELSENTRY._serialized_options = b'8\001'
  _globals['_RESPONSE']._serialized_start=266
  _globals['_RESPONSE']._serialized_end=1113
  _globals['_BATCHWRITERESPONSE']._serialized_start=1116
  _globals['_BATCHWRITERESPONSE']._serialized_end=1301
  _globals['_BATCHQUERYRESPONSE']._serialized_start=1304
  _globals['_BATCHQUERYRESPONSE']._serialized_end=1951
  _globals['_DISCOVERRESPONSE']._serialized_start=1954
  _globals['_DISCOVERRESPONSE']._serialized_end=2730
  _globals['_DISCOVERRESPONSE_DISCOVERRESPONSETYPE']._serialized_start=2476
  _globals['_DISCOVERRESPONSE_DISCOVERRESPONSETYPE']._serialized_end=2724
  _globals['_OPTIONSWITCH']._serialized_start=2732
  _globals['_OPTIONSWITCH']._serialized_end=2842
  _globals['_OPTIONSWITCH_OPTIONSENTRY']._serialized_start=2796
  _globals['_OPTIONSWITCH_OPTIONSENTRY']._serialized_end=2842
  _globals['_INSTANCELABELS']._serialized_start=2844
  _globals['_INSTANCELABELS']._serialized_end=2971
  _globals['_INSTANCELABELS_LABELSENTRY']._serialized_start=2910
  _globals['_INSTANCELABELS_LABELSENTRY']._serialized_end=2971
# @@protoc_insertion_point(module_scope)



from google.protobuf import wrappers_pb2 as _wrappers_pb2
from ..service_manage import service_pb2 as _service_pb2
from ..fault_tolerance import circuitbreaker_pb2 as _circuitbreaker_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConfigRelease(_message.Message):
    __slots__ = ["service", "ctime", "mtime", "circuitBreaker"]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    CIRCUITBREAKER_FIELD_NUMBER: _ClassVar[int]
    service: _service_pb2.Service
    ctime: _wrappers_pb2.StringValue
    mtime: _wrappers_pb2.StringValue
    circuitBreaker: _circuitbreaker_pb2.CircuitBreaker
    def __init__(self, service: _Optional[_Union[_service_pb2.Service, _Mapping]] = ..., ctime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., mtime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., circuitBreaker: _Optional[_Union[_circuitbreaker_pb2.CircuitBreaker, _Mapping]] = ...) -> None: ...

class ConfigWithService(_message.Message):
    __slots__ = ["services", "circuitBreaker"]
    SERVICES_FIELD_NUMBER: _ClassVar[int]
    CIRCUITBREAKER_FIELD_NUMBER: _ClassVar[int]
    services: _containers.RepeatedCompositeFieldContainer[_service_pb2.Service]
    circuitBreaker: _circuitbreaker_pb2.CircuitBreaker
    def __init__(self, services: _Optional[_Iterable[_Union[_service_pb2.Service, _Mapping]]] = ..., circuitBreaker: _Optional[_Union[_circuitbreaker_pb2.CircuitBreaker, _Mapping]] = ...) -> None: ...



from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from ..model import model_pb2 as _model_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RateLimit(_message.Message):
    __slots__ = ["rules", "revision"]
    RULES_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    rules: _containers.RepeatedCompositeFieldContainer[Rule]
    revision: _wrappers_pb2.StringValue
    def __init__(self, rules: _Optional[_Iterable[_Union[Rule, _Mapping]]] = ..., revision: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class Rule(_message.Message):
    __slots__ = ["id", "service", "namespace", "subset", "priority", "resource", "type", "labels", "amounts", "action", "disable", "report", "ctime", "mtime", "revision", "service_token", "adjuster", "regex_combine", "amount_mode", "failover", "cluster", "method", "arguments", "name", "etime", "max_queue_delay"]
    class Resource(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        QPS: _ClassVar[Rule.Resource]
        CONCURRENCY: _ClassVar[Rule.Resource]
    QPS: Rule.Resource
    CONCURRENCY: Rule.Resource
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        GLOBAL: _ClassVar[Rule.Type]
        LOCAL: _ClassVar[Rule.Type]
    GLOBAL: Rule.Type
    LOCAL: Rule.Type
    class AmountMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        GLOBAL_TOTAL: _ClassVar[Rule.AmountMode]
        SHARE_EQUALLY: _ClassVar[Rule.AmountMode]
    GLOBAL_TOTAL: Rule.AmountMode
    SHARE_EQUALLY: Rule.AmountMode
    class FailoverType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        FAILOVER_LOCAL: _ClassVar[Rule.FailoverType]
        FAILOVER_PASS: _ClassVar[Rule.FailoverType]
    FAILOVER_LOCAL: Rule.FailoverType
    FAILOVER_PASS: Rule.FailoverType
    class SubsetEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _model_pb2.MatchString
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ...) -> None: ...
    class LabelsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _model_pb2.MatchString
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    SUBSET_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    AMOUNTS_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    DISABLE_FIELD_NUMBER: _ClassVar[int]
    REPORT_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    SERVICE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ADJUSTER_FIELD_NUMBER: _ClassVar[int]
    REGEX_COMBINE_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_MODE_FIELD_NUMBER: _ClassVar[int]
    FAILOVER_FIELD_NUMBER: _ClassVar[int]
    CLUSTER_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ETIME_FIELD_NUMBER: _ClassVar[int]
    MAX_QUEUE_DELAY_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.StringValue
    service: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    subset: _containers.MessageMap[str, _model_pb2.MatchString]
    priority: _wrappers_pb2.UInt32Value
    resource: Rule.Resource
    type: Rule.Type
    labels: _containers.MessageMap[str, _model_pb2.MatchString]
    amounts: _containers.RepeatedCompositeFieldContainer[Amount]
    action: _wrappers_pb2.StringValue
    disable: _wrappers_pb2.BoolValue
    report: Report
    ctime: _wrappers_pb2.StringValue
    mtime: _wrappers_pb2.StringValue
    revision: _wrappers_pb2.StringValue
    service_token: _wrappers_pb2.StringValue
    adjuster: AmountAdjuster
    regex_combine: _wrappers_pb2.BoolValue
    amount_mode: Rule.AmountMode
    failover: Rule.FailoverType
    cluster: RateLimitCluster
    method: _model_pb2.MatchString
    arguments: _containers.RepeatedCompositeFieldContainer[MatchArgument]
    name: _wrappers_pb2.StringValue
    etime: _wrappers_pb2.StringValue
    max_queue_delay: _wrappers_pb2.UInt32Value
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., service: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., subset: _Optional[_Mapping[str, _model_pb2.MatchString]] = ..., priority: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., resource: _Optional[_Union[Rule.Resource, str]] = ..., type: _Optional[_Union[Rule.Type, str]] = ..., labels: _Optional[_Mapping[str, _model_pb2.MatchString]] = ..., amounts: _Optional[_Iterable[_Union[Amount, _Mapping]]] = ..., action: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., disable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., report: _Optional[_Union[Report, _Mapping]] = ..., ctime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., mtime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., revision: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., service_token: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., adjuster: _Optional[_Union[AmountAdjuster, _Mapping]] = ..., regex_combine: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., amount_mode: _Optional[_Union[Rule.AmountMode, str]] = ..., failover: _Optional[_Union[Rule.FailoverType, str]] = ..., cluster: _Optional[_Union[RateLimitCluster, _Mapping]] = ..., method: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ..., arguments: _Optional[_Iterable[_Union[MatchArgument, _Mapping]]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., etime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., max_queue_delay: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ...) -> None: ...

class MatchArgument(_message.Message):
    __slots__ = ["type", "key", "value"]
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        CUSTOM: _ClassVar[MatchArgument.Type]
        METHOD: _ClassVar[MatchArgument.Type]
        HEADER: _ClassVar[MatchArgument.Type]
        QUERY: _ClassVar[MatchArgument.Type]
        CALLER_SERVICE: _ClassVar[MatchArgument.Type]
        CALLER_IP: _ClassVar[MatchArgument.Type]
    CUSTOM: MatchArgument.Type
    METHOD: MatchArgument.Type
    HEADER: MatchArgument.Type
    QUERY: MatchArgument.Type
    CALLER_SERVICE: MatchArgument.Type
    CALLER_IP: MatchArgument.Type
    TYPE_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    type: MatchArgument.Type
    key: str
    value: _model_pb2.MatchString
    def __init__(self, type: _Optional[_Union[MatchArgument.Type, str]] = ..., key: _Optional[str] = ..., value: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ...) -> None: ...

class RateLimitCluster(_message.Message):
    __slots__ = ["service", "namespace"]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    service: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    def __init__(self, service: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class Amount(_message.Message):
    __slots__ = ["maxAmount", "validDuration", "precision", "startAmount", "minAmount"]
    MAXAMOUNT_FIELD_NUMBER: _ClassVar[int]
    VALIDDURATION_FIELD_NUMBER: _ClassVar[int]
    PRECISION_FIELD_NUMBER: _ClassVar[int]
    STARTAMOUNT_FIELD_NUMBER: _ClassVar[int]
    MINAMOUNT_FIELD_NUMBER: _ClassVar[int]
    maxAmount: _wrappers_pb2.UInt32Value
    validDuration: _duration_pb2.Duration
    precision: _wrappers_pb2.UInt32Value
    startAmount: _wrappers_pb2.UInt32Value
    minAmount: _wrappers_pb2.UInt32Value
    def __init__(self, maxAmount: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., validDuration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., precision: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., startAmount: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., minAmount: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ...) -> None: ...

class Report(_message.Message):
    __slots__ = ["interval", "amountPercent"]
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    AMOUNTPERCENT_FIELD_NUMBER: _ClassVar[int]
    interval: _duration_pb2.Duration
    amountPercent: _wrappers_pb2.UInt32Value
    def __init__(self, interval: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., amountPercent: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ...) -> None: ...

class AmountAdjuster(_message.Message):
    __slots__ = ["climb"]
    CLIMB_FIELD_NUMBER: _ClassVar[int]
    climb: ClimbConfig
    def __init__(self, climb: _Optional[_Union[ClimbConfig, _Mapping]] = ...) -> None: ...

class ClimbConfig(_message.Message):
    __slots__ = ["enable", "metric", "policy", "throttling"]
    class MetricConfig(_message.Message):
        __slots__ = ["window", "precision", "reportInterval"]
        WINDOW_FIELD_NUMBER: _ClassVar[int]
        PRECISION_FIELD_NUMBER: _ClassVar[int]
        REPORTINTERVAL_FIELD_NUMBER: _ClassVar[int]
        window: _duration_pb2.Duration
        precision: _wrappers_pb2.UInt32Value
        reportInterval: _duration_pb2.Duration
        def __init__(self, window: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., precision: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., reportInterval: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...
    class TriggerPolicy(_message.Message):
        __slots__ = ["errorRate", "slowRate"]
        class ErrorRate(_message.Message):
            __slots__ = ["enable", "requestVolumeThreshold", "errorRate", "specials"]
            class SpecialConfig(_message.Message):
                __slots__ = ["type", "errorCodes", "errorRate"]
                TYPE_FIELD_NUMBER: _ClassVar[int]
                ERRORCODES_FIELD_NUMBER: _ClassVar[int]
                ERRORRATE_FIELD_NUMBER: _ClassVar[int]
                type: _wrappers_pb2.StringValue
                errorCodes: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.Int64Value]
                errorRate: _wrappers_pb2.Int32Value
                def __init__(self, type: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., errorCodes: _Optional[_Iterable[_Union[_wrappers_pb2.Int64Value, _Mapping]]] = ..., errorRate: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ...) -> None: ...
            ENABLE_FIELD_NUMBER: _ClassVar[int]
            REQUESTVOLUMETHRESHOLD_FIELD_NUMBER: _ClassVar[int]
            ERRORRATE_FIELD_NUMBER: _ClassVar[int]
            SPECIALS_FIELD_NUMBER: _ClassVar[int]
            enable: _wrappers_pb2.BoolValue
            requestVolumeThreshold: _wrappers_pb2.UInt32Value
            errorRate: _wrappers_pb2.Int32Value
            specials: _containers.RepeatedCompositeFieldContainer[ClimbConfig.TriggerPolicy.ErrorRate.SpecialConfig]
            def __init__(self, enable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., requestVolumeThreshold: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., errorRate: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ..., specials: _Optional[_Iterable[_Union[ClimbConfig.TriggerPolicy.ErrorRate.SpecialConfig, _Mapping]]] = ...) -> None: ...
        class SlowRate(_message.Message):
            __slots__ = ["enable", "maxRt", "slowRate"]
            ENABLE_FIELD_NUMBER: _ClassVar[int]
            MAXRT_FIELD_NUMBER: _ClassVar[int]
            SLOWRATE_FIELD_NUMBER: _ClassVar[int]
            enable: _wrappers_pb2.BoolValue
            maxRt: _duration_pb2.Duration
            slowRate: _wrappers_pb2.Int32Value
            def __init__(self, enable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., maxRt: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., slowRate: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ...) -> None: ...
        ERRORRATE_FIELD_NUMBER: _ClassVar[int]
        SLOWRATE_FIELD_NUMBER: _ClassVar[int]
        errorRate: ClimbConfig.TriggerPolicy.ErrorRate
        slowRate: ClimbConfig.TriggerPolicy.SlowRate
        def __init__(self, errorRate: _Optional[_Union[ClimbConfig.TriggerPolicy.ErrorRate, _Mapping]] = ..., slowRate: _Optional[_Union[ClimbConfig.TriggerPolicy.SlowRate, _Mapping]] = ...) -> None: ...
    class ClimbThrottling(_message.Message):
        __slots__ = ["coldBelowTuneDownRate", "coldBelowTuneUpRate", "coldAboveTuneDownRate", "coldAboveTuneUpRate", "limitThresholdToTuneUp", "judgeDuration", "tuneUpPeriod", "tuneDownPeriod"]
        COLDBELOWTUNEDOWNRATE_FIELD_NUMBER: _ClassVar[int]
        COLDBELOWTUNEUPRATE_FIELD_NUMBER: _ClassVar[int]
        COLDABOVETUNEDOWNRATE_FIELD_NUMBER: _ClassVar[int]
        COLDABOVETUNEUPRATE_FIELD_NUMBER: _ClassVar[int]
        LIMITTHRESHOLDTOTUNEUP_FIELD_NUMBER: _ClassVar[int]
        JUDGEDURATION_FIELD_NUMBER: _ClassVar[int]
        TUNEUPPERIOD_FIELD_NUMBER: _ClassVar[int]
        TUNEDOWNPERIOD_FIELD_NUMBER: _ClassVar[int]
        coldBelowTuneDownRate: _wrappers_pb2.Int32Value
        coldBelowTuneUpRate: _wrappers_pb2.Int32Value
        coldAboveTuneDownRate: _wrappers_pb2.Int32Value
        coldAboveTuneUpRate: _wrappers_pb2.Int32Value
        limitThresholdToTuneUp: _wrappers_pb2.Int32Value
        judgeDuration: _duration_pb2.Duration
        tuneUpPeriod: _wrappers_pb2.Int32Value
        tuneDownPeriod: _wrappers_pb2.Int32Value
        def __init__(self, coldBelowTuneDownRate: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ..., coldBelowTuneUpRate: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ..., coldAboveTuneDownRate: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ..., coldAboveTuneUpRate: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ..., limitThresholdToTuneUp: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ..., judgeDuration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., tuneUpPeriod: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ..., tuneDownPeriod: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ...) -> None: ...
    ENABLE_FIELD_NUMBER: _ClassVar[int]
    METRIC_FIELD_NUMBER: _ClassVar[int]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    THROTTLING_FIELD_NUMBER: _ClassVar[int]
    enable: _wrappers_pb2.BoolValue
    metric: ClimbConfig.MetricConfig
    policy: ClimbConfig.TriggerPolicy
    throttling: ClimbConfig.ClimbThrottling
    def __init__(self, enable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., metric: _Optional[_Union[ClimbConfig.MetricConfig, _Mapping]] = ..., policy: _Optional[_Union[ClimbConfig.TriggerPolicy, _Mapping]] = ..., throttling: _Optional[_Union[ClimbConfig.ClimbThrottling, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from ..model import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rservice.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x0bmodel.proto\"\x9f\x0b\n\x07Service\x12*\n\x04name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x08metadata\x18\x03 \x03(\x0b\x32\x19.v1.Service.MetadataEntry\x12+\n\x05ports\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x62usiness\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\ndepartment\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\tcmdb_mod1\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tcmdb_mod1\x12:\n\tcmdb_mod2\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tcmdb_mod2\x12:\n\tcmdb_mod3\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tcmdb_mod3\x12-\n\x07\x63omment\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06owners\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05token\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x63time\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08revision\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12>\n\x0bplatform_id\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0bplatform_id\x12P\n\x14total_instance_count\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x14total_instance_count\x12T\n\x16healthy_instance_count\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x16healthy_instance_count\x12\x38\n\x08user_ids\x18\x13 \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x08user_ids\x12:\n\tgroup_ids\x18\x14 \x03(\x0b\x32\x1c.google.protobuf.StringValueR\tgroup_ids\x12\x46\n\x0fremove_user_ids\x18\x16 \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x0fremove_user_ids\x12H\n\x10remove_group_ids\x18\x17 \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x10remove_group_ids\x12(\n\x02id\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x08\x65\x64itable\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12:\n\texport_to\x18\x19 \x03(\x0b\x32\x1c.google.protobuf.StringValueR\texport_to\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd3\x04\n\x0cServiceAlias\x12-\n\x07service\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x46\n\x0f\x61lias_namespace\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0f\x61lias_namespace\x12\x1b\n\x04type\x18\x05 \x01(\x0e\x32\r.v1.AliasType\x12,\n\x06owners\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x42\n\rservice_token\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rservice_token\x12+\n\x05\x63time\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12(\n\x02id\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x08\x65\x64itable\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xa2\x08\n\x08Instance\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07service\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x06vpc_id\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06vpc_id\x12*\n\x04host\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04port\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12.\n\x08protocol\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07version\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08priority\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12,\n\x06weight\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x37\n\x13\x65nable_health_check\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12%\n\x0chealth_check\x18\n \x01(\x0b\x32\x0f.v1.HealthCheck\x12+\n\x07healthy\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07isolate\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1e\n\x08location\x18\r \x01(\x0b\x32\x0c.v1.Location\x12,\n\x08metadata\x18\x0e \x03(\x0b\x32\x1a.v1.Instance.MetadataEntry\x12:\n\tlogic_set\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tlogic_set\x12+\n\x05\x63time\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08revision\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x42\n\rservice_token\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rservice_token\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x01\n\x0bHealthCheck\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.v1.HealthCheck.HealthCheckType\x12+\n\theartbeat\x18\x02 \x01(\x0b\x32\x18.v1.HeartbeatHealthCheck\"-\n\x0fHealthCheckType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tHEARTBEAT\x10\x01\"A\n\x14HeartbeatHealthCheck\x12)\n\x03ttl\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value*$\n\tAliasType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\n\n\x06\x43L5SID\x10\x01\x42\x8d\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\x0cServiceProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\014ServiceProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _SERVICE_METADATAENTRY._options = None
  _SERVICE_METADATAENTRY._serialized_options = b'8\001'
  _INSTANCE_METADATAENTRY._options = None
  _INSTANCE_METADATAENTRY._serialized_options = b'8\001'
  _globals['_ALIASTYPE']._serialized_start=3389
  _globals['_ALIASTYPE']._serialized_end=3425
  _globals['_SERVICE']._serialized_start=67
  _globals['_SERVICE']._serialized_end=1506
  _globals['_SERVICE_METADATAENTRY']._serialized_start=1459
  _globals['_SERVICE_METADATAENTRY']._serialized_end=1506
  _globals['_SERVICEALIAS']._serialized_start=1509
  _globals['_SERVICEALIAS']._serialized_end=2104
  _globals['_INSTANCE']._serialized_start=2107
  _globals['_INSTANCE']._serialized_end=3165
  _globals['_INSTANCE_METADATAENTRY']._serialized_start=1459
  _globals['_INSTANCE_METADATAENTRY']._serialized_end=1506
  _globals['_HEALTHCHECK']._serialized_start=3168
  _globals['_HEALTHCHECK']._serialized_end=3320
  _globals['_HEALTHCHECK_HEALTHCHECKTYPE']._serialized_start=3275
  _globals['_HEALTHCHECK_HEALTHCHECKTYPE']._serialized_end=3320
  _globals['_HEARTBEATHEALTHCHECK']._serialized_start=3322
  _globals['_HEARTBEATHEALTHCHECK']._serialized_end=3387
# @@protoc_insertion_point(module_scope)



from ..service_manage import service_pb2 as _service_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HeartbeatRecord(_message.Message):
    __slots__ = ["instanceId", "lastHeartbeatSec", "exist"]
    INSTANCEID_FIELD_NUMBER: _ClassVar[int]
    LASTHEARTBEATSEC_FIELD_NUMBER: _ClassVar[int]
    EXIST_FIELD_NUMBER: _ClassVar[int]
    instanceId: str
    lastHeartbeatSec: int
    exist: bool
    def __init__(self, instanceId: _Optional[str] = ..., lastHeartbeatSec: _Optional[int] = ..., exist: bool = ...) -> None: ...

class InstanceHeartbeat(_message.Message):
    __slots__ = ["instanceId", "service", "namespace", "host", "port"]
    INSTANCEID_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    HOST_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    instanceId: str
    service: str
    namespace: str
    host: str
    port: int
    def __init__(self, instanceId: _Optional[str] = ..., service: _Optional[str] = ..., namespace: _Optional[str] = ..., host: _Optional[str] = ..., port: _Optional[int] = ...) -> None: ...

class HeartbeatsRequest(_message.Message):
    __slots__ = ["heartbeats"]
    HEARTBEATS_FIELD_NUMBER: _ClassVar[int]
    heartbeats: _containers.RepeatedCompositeFieldContainer[InstanceHeartbeat]
    def __init__(self, heartbeats: _Optional[_Iterable[_Union[InstanceHeartbeat, _Mapping]]] = ...) -> None: ...

class HeartbeatsResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetHeartbeatsRequest(_message.Message):
    __slots__ = ["instanceIds"]
    INSTANCEIDS_FIELD_NUMBER: _ClassVar[int]
    instanceIds: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, instanceIds: _Optional[_Iterable[str]] = ...) -> None: ...

class GetHeartbeatsResponse(_message.Message):
    __slots__ = ["records"]
    RECORDS_FIELD_NUMBER: _ClassVar[int]
    records: _containers.RepeatedCompositeFieldContainer[HeartbeatRecord]
    def __init__(self, records: _Optional[_Iterable[_Union[HeartbeatRecord, _Mapping]]] = ...) -> None: ...

class DelHeartbeatsRequest(_message.Message):
    __slots__ = ["instanceIds"]
    INSTANCEIDS_FIELD_NUMBER: _ClassVar[int]
    instanceIds: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, instanceIds: _Optional[_Iterable[str]] = ...) -> None: ...

class DelHeartbeatsResponse(_message.Message):
    __slots__ = ["code", "info"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    code: int
    info: str
    def __init__(self, code: _Optional[int] = ..., info: _Optional[str] = ...) -> None: ...



from .client_pb2_grpc import *
from .grpcapi_pb2_grpc import *
from .request_pb2 import *
from .request_pb2_grpc import *
from .client_pb2 import *
from .heartbeat_pb2 import *
from .grpcapi_pb2 import *
from .heartbeat_pb2_grpc import *
from .contract_pb2 import *
from .response_pb2_grpc import *
from .configrelease_pb2 import *
from .response_pb2 import *
from .service_pb2 import *
from .service_pb2_grpc import *
from .configrelease_pb2_grpc import *
from .contract_pb2_grpc import *